==> openshift-model-clusterautoscaling-5.12.1-sources.jar: io/fabric8/openshift/api/model/clusterautoscaling/v1/GPULimitBuilder.java <==
package io.fabric8.openshift.api.model.clusterautoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GPULimitBuilder extends io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluentImpl<io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit,io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitBuilder>{
  public GPULimitBuilder() {
    this(false);
  }
  public GPULimitBuilder(java.lang.Boolean validationEnabled) {
    this(new GPULimit(), validationEnabled);
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluent<?> fluent) {
    this(fluent, false);
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GPULimit(), validationEnabled);
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluent<?> fluent,io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit instance) {
    this(fluent, instance, false);
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluent<?> fluent,io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMax(instance.getMax()); 
    fluent.withMin(instance.getMin()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit instance) {
    this(instance,false);
  }
  public GPULimitBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMax(instance.getMax()); 
    this.withMin(instance.getMin()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimitFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.clusterautoscaling.v1.GPULimit build() {
    GPULimit buildable = new GPULimit(fluent.getMax(),fluent.getMin(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GPULimitBuilder that = (GPULimitBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-clusterautoscaling-6.5.1-sources.jar: io/fabric8/openshift/api/model/clusterautoscaling/v1/GPULimitBuilder.java <==
package io.fabric8.openshift.api.model.clusterautoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GPULimitBuilder extends GPULimitFluentImpl<GPULimitBuilder> implements VisitableBuilder<GPULimit,GPULimitBuilder>{
  public GPULimitBuilder() {
    this(false);
  }
  public GPULimitBuilder(Boolean validationEnabled) {
    this(new GPULimit(), validationEnabled);
  }
  public GPULimitBuilder(GPULimitFluent<?> fluent) {
    this(fluent, false);
  }
  public GPULimitBuilder(GPULimitFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GPULimit(), validationEnabled);
  }
  public GPULimitBuilder(GPULimitFluent<?> fluent,GPULimit instance) {
    this(fluent, instance, false);
  }
  public GPULimitBuilder(GPULimitFluent<?> fluent,GPULimit instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMax(instance.getMax()); 
    fluent.withMin(instance.getMin()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GPULimitBuilder(GPULimit instance) {
    this(instance,false);
  }
  public GPULimitBuilder(GPULimit instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withMax(instance.getMax()); 
    this.withMin(instance.getMin()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  GPULimitFluent<?> fluent;
  Boolean validationEnabled;
  public GPULimit build() {
    GPULimit buildable = new GPULimit(fluent.getMax(),fluent.getMin(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
